MgLib
=======

Python Package containing modules shared across all `Papermerge Project <https://github.com/ciur/papermerge>`_ project.

Installation
##############

    pip install mglib

Run tests
###########

    python test/run.py


Requirements
##############

    python >= 3.7
